@@ -94,8 +94,14 @@ class Packages():
             ('debian', debian)
             ])
     def dump_all_pkgs(self, opt):
+        def red(str):
+            return colored(str, 'red', attrs=['bold'])
+        def blue(str):
+            return colored(str, 'blue', attrs=['bold'])
+        def green(str):
+            return colored(str, 'green', attrs=['bold'])
         for x in self.config['pkgs']['{}'.format(opt)]:
-            print(x)
+            print(green('{\'') + blue('pkgname') + green('\': \'') + red(x['pkgname']) + green('\','), green('\'') + blue('pkg') + green('\': \'') + red(x['pkg']) + green('\'') + green('}'))
     def generate_full_cmd(self, path, opt):
         cmds = {}
         for x in self.config['pkgs']['{}'.format(opt)]:
@@ -123,9 +129,11 @@ class Packages():
                 tmp.append(x)
             return tmp
         if self.config['pkgman'] == '/usr/bin/pacman':
-            subprocess.call(conc([self.config['sudo'], self.config['pkgman'], '-S'], self.generate_full_cmd(path, 'arch')))
+            if self.generate_full_cmd(path, 'arch') != []:
+                subprocess.call(conc([self.config['sudo'], self.config['pkgman'], '-S'], self.generate_full_cmd(path, 'arch')))
         elif self.config['pkgman'] == '/usr/bin/xbps-install': # Not in use, yet.
-            subprocess.call(conc([self.config['sudo'], self.config['pkgman'], '-S'], self.generate_full_cmd(path, 'void')))
+            if self.generate_full_cmd(path, 'void') != []:
+                subprocess.call(conc([self.config['sudo'], self.config['pkgman'], '-S'], self.generate_full_cmd(path, 'void')))
 
 class Package:
     def __init__(self, name: str, arch_pkg: str, void_pkg: str, gentoo_pkg: str, fedora_pkg: str, debian_pkg: str):
@@ -152,7 +160,6 @@ class Pkgs:
                 for package in _pkgs:
                     self.pkgs.append(UPackage(name=package))
         f.close()
-
 class Deps:
     def __init__(self, file):
         self.file = file
